<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Admin;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;
use App\Validators\Admin\AdminDecisionValidator;
use Illuminate\Support\Facades\Hash;
use App\Managers\Decision\DecisionManager;
use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use App\Managers\DecisionPolls\DecisionPollsManager;
use App\Managers\DecisionPollsOption\DecisionPollsOptionManager;
use App\Managers\User\UserManager;
use App\Jobs\PollEmail;
use Illuminate\Support\Facades\DB;

class AdminDecisionController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->decisionValidator = new AdminDecisionValidator();
        $this->decisionManager = new DecisionManager();
        $this->decisionPolls = new DecisionPollsManager();
        $this->decisionPollsOption = new DecisionPollsOptionManager();
        $this->userManager = new UserManager();
    }
    
    public function add()
    {
        return view('/admin/decision/add');
    }
    
    public function save(Request $request)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'create');
        
        $validation = $this->decisionValidator->add($data);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->decisionManager->add($data);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Decision Saved Successfully'], 200);
    }
    
    public function index()
    {
        $decisions = $this->decisionManager->with('user', 'likes')->orderBy('created_at', 'DESC')->paginate(config('settings.no_of_records'));
        return view('/admin/decision/list')->with('decisions', $decisions);
    }
    
    public function edit($UUID)
    {
        return view('/admin/decision/edit')->with('UUID', $UUID);
    }
    
    public function currentDecisionProposal($UUID)
    {
        $decision = $this->decisionManager->select('*',DB::raw('DATE_FORMAT(expiry_date, "%d %b %Y %H:%i") AS formatted_expiry_date'))->where('UUID', $UUID)->first()->toArray();
        return response()->json($decision,200);
    }
    
    public function currentDecisionPoll($UUID)
    {
        $polls = $this->decisionPolls->select('*',DB::raw('DATE_FORMAT(expiry_date, "%d %b %Y %H:%i") AS formatted_expiry_date'))->with('options')->where('UUID', $UUID)->first()->toArray();
        return response()->json($polls,200);
    }
    
    public function currentDecisionPollView($UUID)
    {
        $polls = $this->decisionPolls->select('*',DB::raw('DATE_FORMAT(expiry_date, "%d %b %Y %H:%i") AS formatted_expiry_date'))->with('options')->where('UUID', $UUID)->first()->toArray();
        return view('/admin/decision/polls/view')->with('UUID', $UUID)->with('polls', $polls);
    }
    
    public function update(Request $request, $UUID)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'update');
        
        $validation = $this->decisionValidator->update($data, $UUID);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $data['expiry_date'] = date("Y-m-d H:i", strtotime($data['expiry_date']));
        $team = $this->decisionManager->updateData($data, $UUID);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Decision Updated Successfully'], 200);
    }
    
    public function updateDecisionPolls(Request $request, $UUID)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        
        $validation = $this->decisionValidator->addPolls($data, $UUID);
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->decisionPolls->updateData($data, $UUID);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Decision Updated Successfully'], 200);
    }
    
    public function deleteDecisionPolls($UUID)
    {
        $this->decisionPollsOption->where('decision_polls_id', $UUID)->delete();
        $res = $this->decisionPolls->where('UUID', $UUID)->delete();
        if(!$res)
        {
            return redirect('/admin/decision/polls')->withErrors(['Something Went Wrong']);
            exit;
        }
        
        return redirect('/admin/decision/polls')->withErrors(['Deleted Successfully']);
            exit;
    }
    
    public function confirmProposal(Request $request)
    {
        if(!$request->exists('id'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $id = $request->get('id');
        $confirm = $this->decisionManager->confirmProposal($id);
        if(!$confirm)
        {
             return response()->json(['Something went wrong'], 500);
        }
        return response()->json(['Proposal Confrimed'], 200);
    }
    
    public function denyProposal(Request $request)
    {
        if(!$request->exists('id'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $id = $request->get('id');
        $confirm = $this->decisionManager->denyProposal($id);
        if(!$confirm)
        {
             return response()->json(['Something went wrong'], 500);
        }
        return response()->json(['Proposal Confrimed'], 200);
    }
    
    public function decisionPolls(Request $request)
    {
        $decisions = $this->decisionPolls->get();
        return view('/admin/decision/polls/list')->with('decisions', $decisions);
    }
    
    public function createDecisionPolls(Request $request)
    {
        return view('/admin/decision/polls/add');
    }
    
    public function editDecisionPolls($UUID)
    {
        
        return view('/admin/decision/polls/edit')->with('UUID', $UUID);
    }
    
    public function addDecisionPoll(Request $request)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        //$data = $this->helper->changeSerialzeArrayValues($data, 'create');
        $validation = $this->decisionValidator->addPolls($data);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        $team = $this->decisionPolls->add($data, $request->session()->get('admin'));
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        $users = $this->userManager->where('type','general')->where('active', 1)->get();
       
        if($data['default_poll'] == 1)
        {
//            foreach($users AS $user)
//            {
                //dispatch(new PollEmail($users));
                $emailArray = array();
                $users = $this->userManager->where('users.type','general')->join('paypal', 'users.UUID', '=', 'paypal.user_id')->where('users.active', 1)->where('paypal.expiry_date', '>=', date("Y-m-d"))->get();

                foreach($users AS $user)
                {
                    $emailArray[] = trim($user->email);
                }

                Mail::send('emails.polls-new', ['text' => 'view', 'url' => url('/')], function($message) use ($emailArray)
                {  
                    $message->from('info@realclubmanager.com', 'SUPPORTER 2.0');
                    $message->to('contact@realclubmanager.com');
                    
                    $message->bcc($emailArray);
                    $message->subject('Decizie supusa la vot');    
                });
                
    //        }
        }
        
        return response()->json(['Poll Addedd Successfully'], 200);
    }
    
    public function updateDecisionPollOption(Request $request, $pollID, $pollsOptionID)
    {
        if(!$request->all() || !$request->exists('option'))
        {
            return response()->json(['No Input Found'], 400);
            exit;
        }
        
        $option = $request->get('option');
        
        $res = $this->decisionPollsOption->where('UUID', $pollsOptionID)->where('decision_polls_id', $pollID)->update(array('options' => $option));
        if(!$res)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Option Updated Successfully'], 200);
    }
    
    public function deletePoll($UUID)
    {
        $res = $this->decisionPolls->deleteData($UUID);
        if(!$res){
            return response()->json(['Something went wrong'], 500);
            exit;
        }
        
        return response()->json(['Proposal Deleted'], 200);
            exit;
    }
    
    public function delete($UUID)
    {
        $res = $this->decisionManager->deleteData($UUID);
        if(!$res){
            return response()->json(['Something went wrong'], 500);
            exit;
        }
        
        return response()->json(['Proposal Deleted'], 200);
            exit;
    }
}