<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Admin;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;
use App\Validators\TransactionValidator;
use Illuminate\Support\Facades\Hash;
use App\Managers\Transaction\TransactionManager;
use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\DB;
use App\Managers\Paypal\PaypalManager;

use App\Managers\Profile\ProfileManager;

class AdminTransactionController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->transactionValidator = new TransactionValidator();
        $this->transactionManager = new TransactionManager();
        $this->paypal = new PaypalManager();
        $this->profileManager = new ProfileManager();
    }
    
    public function add()
    {
        return view('/admin/transactions/add');
    }
    
    public function save(Request $request)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'create');
        
        $validation = $this->transactionValidator->add($data);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $data['date_date'] = date("Y-m-d", strtotime($data['date_date']));
        $team = $this->transactionManager->add($data);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Transaction Saved Successfully'], 200);
    }
    
    public function list(Request $request)
    {
        $profile = $this->profileManager->first();
        $data = array();
        $fromDate = '';
        $toDate = '';

        if($request->exists('data'))
        {
            $data = $request->get('data');
            $fromDate = $data['from_date'];
            $toDate = $data['to_date'];
            
        }

        $transactions = $this->transactionManager
                            ->where(function($query) use ($fromDate)
                            {
                                if(trim($fromDate) != '')
                                {
                                    $query->where('date_date', '>=', date("Y-m-d", strtotime($fromDate)));
                                }
                            })
                            ->where(function($query) use ($toDate)
                            {
                                if(trim($toDate) != '')
                                {
                                    $query->where('date_date', '>=', date("Y-m-d", strtotime($toDate)));
                                }
                            })
                            ->orderBy('date_date')->paginate(200);

        $creditTransactions = $this->transactionManager
                            ->where(function($query) use ($fromDate)
                            {
                                if(trim($fromDate) != '')
                                {
                                    $query->where('date_date', '>=', date("Y-m-d", strtotime($fromDate)));
                                }
                            })
                            ->where(function($query) use ($toDate)
                            {
                                if(trim($toDate) != '')
                                {
                                    $query->where('date_date', '>=', date("Y-m-d", strtotime($toDate)));
                                }
                            })
                            ->where('credit', 1)
                            ->orderBy('date_date')->sum('amount');

        $debitTransactions = $this->transactionManager
                            ->where(function($query) use ($fromDate)
                            {
                                if(trim($fromDate) != '')
                                {
                                    $query->where('date_date', '>=', date("Y-m-d", strtotime($fromDate)));
                                }
                            })
                            ->where(function($query) use ($toDate)
                            {
                                if(trim($toDate) != '')
                                {
                                    $query->where('date_date', '>=', date("Y-m-d", strtotime($toDate)));
                                }
                            })
                            ->where('credit', 0)
                            ->orderBy('date_date')->sum('amount');

        $total_revenue = $this->paypal->join('users', 'users.uuid', '=', 'paypal.user_id')->sum('payment_gross');
        return view('/admin/transactions/list')->with('transactions', $transactions)->with('creditTransactions', $creditTransactions)->with('debitTransactions', $debitTransactions)->with('total_revenue', $total_revenue)->with('data', $data)->with('profile', $profile);
    }
    
    public function edit($UUID)
    {
        $transaction = $this->transactionManager->where('UUID', $UUID)->first();
        return view('/admin/transactions/edit')->with('transaction', $transaction)->with('UUID', $UUID);
    }
    
    public function update(Request $request, $UUID)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        
        $data = $this->helper->changeSerialzeArrayValues($data, 'update');
        $validation = $this->transactionValidator->update($data, $UUID);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $data['date_date'] = date("Y-m-d", strtotime($data['date_date']));
        $team = $this->transactionManager->updateData($data, $UUID);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Transaction Updated Successfully'], 200);
    }
    
   
    public function delete($UUID)
    {
        $res = $this->transactionManager->deleteData($UUID);
        if(!$res){
            return response()->json(['Something went wrong'], 500);
            exit;
        }
        
        return response()->json(['Transaction Deleted'], 200);
            exit;
    }
    
}