<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Http\Controllers\Admin;
use Illuminate\Http\Request;
use App\Http\Helper\Helper;
use App\Validators\Admin\AdminUserValidator;
use Illuminate\Support\Facades\Hash;
use App\Managers\User\UserManager;
use Illuminate\Support\Facades\Mail;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Redirect;
use App\Managers\Paypal\PaypalManager;
use Illuminate\Support\Facades\DB;

class AdminUserController extends Controller
{
    public function __construct()
    {
        $this->helper = new Helper();
        $this->userValidator = new AdminUserValidator();
        $this->userManager = new UserManager();
        $this->paypal = new PaypalManager();
    }
    
    public function add()
    {
        return view('/admin/user/add');
    }
    
    public function save(Request $request)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'create');
        
        $validation = $this->userValidator->add($data);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->userManager->add($data);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Team Saved Successfully'], 200);
    }
    
    public function index(Request $request)
    {
        $data['name'] = '';
        $data['email'] = '';
      
        if($request->exists('data'))
        {
            $data = $request->get('data');
            
        }
        $users = $this->userManager->select('users.*')->leftJoin('paypal', 'paypal.user_id', '=', 'users.UUID')->whereNull('users.deleted_at')->where('users.email', '!=', 'admin@admin.com')
                ->where(function($query) use ($data)
                {
                    if(trim($data['name']) != '')
                    {
                        $query->where('users.name', 'LIKE', $data['name'] . '%');
                    }

                    if(trim($data['email']) != '')
                    {
                        $query->where('users.email', 'LIKE', $data['email'] . '%');
                    }

                    if(isset($data['notification']))
                    {
                        $query->where('users.notification', 1);
                    }

                    if(isset($data['active']))
                    {
                        $query->where('users.confirmation_code', 1);
                    }
                })
                ->orderBy('users.created_at', 'DESC')->groupBy('users.UUID')->paginate(200);
        return view('/admin/user/list')->with('users', $users);
    }
    
    public function edit($UUID)
    {
        $users = $this->userManager->where('type', 'admin')->get();
        return view('/admin/user/edit')->with('UUID', $UUID)->with('users', $users);
    }
    
    public function currentUser($UUID)
    {
        $team = $this->userManager->where('UUID', $UUID)->first()->toArray();
        return response()->json($team,200);
    }
    
    public function update(Request $request, $UUID)
    {
        if(!$request->all() || !$request->exists('data'))
        {
            return response()->json(['No Input Found'], 400);
        }
        $data = $request->get('data');
        $data = $this->helper->changeSerialzeArrayValues($data, 'update');
        
        $validation = $this->userValidator->update($data, $UUID);
        
        if($validation)
        {
            return response()->json($validation['errors'], 400);
        }
        
        $team = $this->userManager->updateData($data, $UUID);
        if(!$team)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['Team Updated Successfully'], 200);
    }
    
    public function delete($UUID)
    {
        $delete = $this->userManager->deleteData($UUID);
        if(!$delete)
        {
            return response()->json(['Something went wrong'], 500);
        }
        
        return response()->json(['User Deleted Successfully'], 200);
    }
    
    public function userPayments($userID)
    {
        $payments = $this->paypal->getAllCreditsOfUser($userID);
        return response()->json($payments, 200);
    }
    
    public function userVotesAdd(Request $request, $userID)
    {
        if($request->exists('data'))
        {
            $data = $request->get('data');
            $res = $this->paypal->addVotes($data, $userID);
            if(!$res)
            {
                return response()->json('Something went wrong', 500);
                exit;
            }
            
            return response()->json('Votes Added Successfully', 200);
            exit;
        }
    }
    
    public function deleteVote($id)
    {
        $del = $this->paypal->where('UUID', $id)->delete();
        if(!$del)
        {
            return response()->json('Something went wrong', 500);
            exit;
        }
        
        return response()->json('Votes Deleted Successfully', 200);
        exit;
    }
    
    public function userPaymentsList()
    {
        $users = $this->userManager->where('type', 'general')->get();
        return view('/admin/user/payment_list')->with('users', $users);
    }
    
    public function userPaymentsAll(Request $request, $page)
    {
        $userID = $request->get('userID');
        $voteThrough = '';
        $voteStatus = '';
        if($request->exists('voteStatus'))
        {
            $voteStatus = $request->get('voteStatus');
        }
        if($request->exists('voteThrough'))
        {
            $voteThrough = $request->get('voteThrough');
        }
        $payments = $this->paypal
                ->select('paypal.*', 'u1.phone AS main_user_phone','u1.name AS main_user_name','u1.country', 'u1.email AS main_user_email', 'u2.name AS admin_user_name','u2.email AS admin_email', DB::raw('DATE_FORMAT(paypal.expiry_date, "%d %M %Y") AS expiry_date_formatted'), DB::raw('DATE_FORMAT(paypal.payment_date, "%d %M %Y  %H:%i") AS payment_date_formatted'), DB::raw('DATE_FORMAT(paypal.created_at, "%d %M %Y %H:%i") AS created_at_formatted'))
                ->join('users AS u1', 'u1.uuid', '=', 'paypal.user_id')
                ->leftJoin('users AS u2', 'u2.uuid', '=', 'paypal.admin_user_id')
                ->where(function($query) use ($userID)
                {
                    if($userID != '')
                    {
                        $query->where('paypal.user_id', '=', $userID);
                    }
                })
                ->where(function($query) use ($voteStatus)
                {
                    if($voteStatus == 'active')
                    {
                        $query->where('paypal.expiry_date', '<', date("Y-m-d"));
                    }
                    else if($voteStatus == 'expired')
                    {
                        $query->where('paypal.expiry_date', '>=', date("Y-m-d"));
                    }
                })
                ->where(function($query) use ($voteThrough)
                {
                    if($voteThrough == 'admin')
                    {
                        $query->where('paypal.type', '=', 'Admin');
                    }
                    else if($voteThrough == 'mobilpay')
                    {
                        $query->where('paypal.type', '=', 'MobilPay');
                    }
                })
                ->orderBy('paypal.created_at')
                ->groupBY('paypal.UUID')
               // ->skip($page * config('settings.no_of_records'))->take(config('settings.no_of_records'))
                //->skip(0)->take(10)
                ->get();
        return response()->json($payments);
    }
    
    public function userPaymentsExpiredNotExpired($userID)
    {
        $user = $this->userManager->where('type', 'general')->where('UUID', $userID)->first();
        return view('/admin/user/current_user_payments')->with('user', $user);
    }
    
    public function totalUserVoteCount($UUID)
    {
        $votes = $this->paypal->getCurrentUserTotalVotesCount($UUID);
        echo $votes['total'];
    }

    public function updateVote(Request $request, $voteID)
    {
        if(!$request->all() || !$request->exists('expiryDate'))
        {
            return response()->json('Something went wrong', 500);
            exit;
        }

        $expiryDate = date("Y-m-d", strtotime($request->get('expiryDate')));

        $data1['expiry_date'] = $expiryDate;
        $data1['description'] = 'Admin Changed expiry Date to ' . $expiryDate . '.<br/> No. of Votes: 1. <br/><br/><br/>';


        $res = $this->paypal->where('UUID', $voteID)->update($data1);
        if(!$res)
        {
            return response()->json('Something went wrong', 500);
            exit;
        }

        return response()->json('Updated Successfully', 200);
            exit;
    }

    public function sortUserByFirstPayment()
    {
        $users = $this->paypal->select('users.*', 'paypal.expiry_date', 'paypal.created_at AS payment_created_at')->join('users', 'users.UUID', '=', 'paypal.user_id')->where('users.active', 1)->where('paypal.expiry_date', '>=', date("Y-m-d"))->groupBY('users.UUID')->orderBy('paypal.created_at')->paginate(200);
        return view('admin/user/user_sort_by_payment')->with('users', $users);
    }
}